@@ -19,7 +19,6 @@ from typing import List, Tuple, Optional, Union, Type
 from collections import OrderedDict
 import sys
 import zeep
-from itertools import zip_longest
 sys.path.append("..")
 try:
     from custom_exceptions.salesforce_exceptions import *
@@ -568,7 +567,7 @@ class Sf:
         return await async_query(query, excludedFields)
     
     async def async_queries(self, queries: List[str]):
-        async_queries = async_wrap(self.sf.query_all)
+        async_queries = async_wrap(self.sf.query)
         result_list = await asyncio.gather(*[async_queries(query) for query in queries])
         result_pd_list = [transform_sf_result_set_rec(result['records']) for result in result_list]
         return result_pd_list
@@ -660,10 +659,7 @@ class Sf:
             ## [0,2] -> ['Web', 'Partner Reference']
             final_result_pd['validFor'] = final_result_pd.apply(lambda row: "\n".join([{v: k for k, v in row['controllerValues'].items()}[value] for value in row['validFor']]), axis=1)
             final_result_pd.drop(columns=['controllerValues'], inplace=True)
-            if final_result_pd['defaultValue'].isnull().all():
-                final_result_pd[['defaultValueLabel', 'defaultValueValue']] = np.nan
-            else:
-                final_result_pd[['defaultValueLabel', 'defaultValueValue']] = json_normalize(final_result_pd['defaultValue'])[['label','value']]
+            final_result_pd[['defaultValueLabel', 'defaultValueValue']] = json_normalize(final_result_pd['defaultValue'])[['label','value']]
             final_result_pd.drop(columns=['defaultValue'], inplace=True)
             final_result_pd = pd.merge(final_result_pd, controlling_fields, left_on='Field_API', right_on='Field', how='left').drop(columns=['Field']).copy()
             final_result_pd['RecordTypeName'] = record_type_name
@@ -683,56 +679,6 @@ class Sf:
         result_list = [item for sublist in result_list for item in sublist]
         return result_list
 
-
-    async def retrieve_metadata(self, metadata_type: list[str]):
-        
-        """Providing a list of metadata type in accordance with the Salesforce Metadata API
-        https://developer.salesforce.com/docs/atlas.en-us.api_meta.meta/api_meta/meta_types_list.htm
-
-        Raises:
-            Exception: Metadata Name Mismatch, this may be caused by async operation returning metadata in unexpected order, or one of the metadata types requestd cannot be retreived properly
-
-        Returns:
-            pd.DataFrame: Returns the full detailed metadata dataframe of all the metadata types requested
-        """
-        metadata_list_async = async_wrap(self.metadata_list)
-        task_list = []
-        for group in self.grouper(metadata_type, 3):
-            meta_list = [value for value in group if value is not None]
-            task_list.append(meta_list)
-        result_list = await asyncio.gather(*[metadata_list_async(metadata_type_list=task ) for task in task_list])
-        result_list = [item for sublist in result_list for item in sublist]
-        metadata_info = pd.DataFrame(zeep.helpers.serialize_object(result_list))
-        
-        
-        metadata_read_async = async_wrap(self.metadata_read)
-        
-        detailed_metadata = await asyncio.gather(*[metadata_read_async(metadata_type=result['type'], fullName=result['fullName']) for result in result_list])
-        
-        
-        combined_metadata = []
-        for item in zip(detailed_metadata, metadata_info.iterrows()):
-            
-            x_data = item[0].loc[0]
-            x_info = item[1][1]
-
-
-            if x_info['fullName'] == x_data['fullName']:
-                x_data.drop('fullName', inplace=True)
-            else:
-                raise Exception('Metadata Name Mismatch, this may be caused by async operation returning metadata in unexpected order, or one of the metadata types requestd cannot be retreived properly')
-            x_info.name= 0
-            
-            combined_row = pd.DataFrame(pd.concat([x_info, x_data], axis=0)).T
-            combined_metadata.append(combined_row)
-        if len(combined_result_df) > 1:
-            combined_result_df = pd.concat(combined_metadata, axis=0).reset_index(drop=True)
-        else:
-            combined_result_df.reset_index(drop=True, inplace=True)
-        
-        return combined_result_df
-
-        
     async def field_permission_bulk_check(self, objects: list, ) -> dict[str, pd.DataFrame]:
         async_field_permission_check = async_wrap(self.field_permission_check)
         result_list = await asyncio.gather(*[async_field_permission_check( object ) for object in objects])
@@ -1230,9 +1176,12 @@ class Sf:
         
         return {'permissionSetPermissions': permissionSetPermissions, 'profilePermissions': profilePermissions}
 
-    async def field_permission_user_check(self, objects, permissions, users=[]):
+    async def field_permission_user_check(self, objects: list[str], permissions: list[str], users=None) -> pd.DataFrame:
         # Similar to the field_permission_check function, but this one will return a list of users that have the specified permission on the specified object
         
+        # this is to avoid having a mutable default argument
+        users = [] if users is None else users
+        
         object_query = "','".join(objects)
         permission_query = ' OR '.join([f"({permission} = true)" for permission in permissions])
 
@@ -1262,6 +1211,9 @@ class Sf:
                                                                 IN ('{relevant_ps_and_profiles_list}')
                                                                 {user_query} AND Assignee.IsActive = TRUE""")['records'])
         
+        if len(data) == 0:
+            return pd.DataFrame(columns=['UserName', 'Profile', 'Field API Name', 'Object API Name','Permission', 'Permission Set'])
+        
         # Retrieve Profile FLS data
         profiles = data[data['PermissionSet.IsOwnedByProfile']]['Profile.Name'].unique().tolist()
         profiles = ['Admin' if x == 'System Administrator' else x for x in profiles]
@@ -1322,7 +1274,7 @@ class Sf:
                 return pd.merge(profile_fls_final, ps_fls_final, on=['UserName','Object API Name', 'Field API Name','Permission'], how='outer')
         else:
                 return pd.DataFrame(columns=['UserName', 'Profile', 'Field API Name', 'Object API Name','Permission', 'Permission Set'])
-            
+          
             
     # Retrieves the Page Layout by Profile by Record Type data for all objects in the org
     def retrieve_profile_layout_record_type_matrix_all(self, return_pivot_table = False):
@@ -1478,22 +1430,7 @@ class Sf:
                 return r.json()
         else:
             raise Exception('API error when calling %s : %s' % (r.url, r.content))
-        
-    def grouper(self, iterable, n, *, incomplete='fill', fillvalue=None):
-        "Collect data into non-overlapping fixed-length chunks or blocks"
-        # grouper('ABCDEFG', 3, fillvalue='x') --> ABC DEF Gxx
-        # grouper('ABCDEFG', 3, incomplete='strict') --> ABC DEF ValueError
-        # grouper('ABCDEFG', 3, incomplete='ignore') --> ABC DEF
-        args = [iter(iterable)] * n
-        if incomplete == 'fill':
-            return zip_longest(*args, fillvalue=fillvalue)
-        if incomplete == 'strict':
-            return zip(*args, strict=True)
-        if incomplete == 'ignore':
-            return zip(*args)
-        else:
-            raise ValueError('Expected fill, strict, or ignore')
-        
+
 
     def join(self, 
                 dataframe, 
